/*
 * $Id: cilk-lib.h,v 1.8 2000/05/25 20:02:24 athena Exp $
 */
/*
 * Copyright (c) 2000 Massachusetts Institute of Technology
 * Copyright (c) 2000 Matteo Frigo
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef _CILK_LIB_H
#define _CILK_LIB_H

#include <cilk.h>

/***********************************************************\
 * Memory allocator functions
\***********************************************************/

extern void *Cilk_alloca_internal(CilkWorkerState *const ws, size_t size);
extern __nooutput__ void *Cilk_alloca(size_t size);

/***********************************************************\
 * Cilk_exit
\***********************************************************/

extern cilk void Cilk_really_exit(int retval);

/* Cilk_exit */
#define Cilk_exit(ret)  			\
do {						\
     spawn Cilk_really_exit(ret);		\
} while (0)


extern void Cilk_die(const char *fmt,...);

/***********************************************************\
 * locks
\***********************************************************/
typedef volatile int Cilk_lockvar[1];

static inline void Cilk_lock_init(Cilk_lockvar v)
{
     v[0] = 0;
}

static inline void Cilk_lock(Cilk_lockvar v)
{
     while (Cilk_xchg((int *)v, 1) != 0) {
	  while (v[0]);  /* spin using only reads - reduces bus traffic */
     }
}

static inline void Cilk_unlock(Cilk_lockvar v)
{
     Cilk_membar_StoreStore();
     v[0] = 0;
}

/***********************************************************\
 * Debugging support
\***********************************************************/

#ifdef	NDEBUG
#define Cilk_assert(ex) ((void)0)
#else
#define Cilk_assert(ex) \
      (void)((ex) || (Cilk_die(NULL, USE_PARAMETER(assertion_failed_msg), \
             #ex, __LINE__, __FILE__), 0))
#endif

/***********************************************************\
 * Real and pseudo variables
\***********************************************************/
#define Cilk_active_size USE_PARAMETER(active_size)

#ifdef __CILK2C__
/* support for referencing part of the worker state */
extern __nooutput__ __cilkonly__ int Self;
extern __nooutput__ __cilkonly__ Cilk_time Cilk_user_work;
extern __nooutput__ __cilkonly__ Cilk_time Cilk_user_critical_path;
#endif

#endif				/* _CILK_LIB_H */
